==> haskell-ghc-typelits-extra-0.3-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ghc-typelits-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ghc-typelits-extra
version: 0.3
id: ghc-typelits-extra-0.3-E6dhYIH37ba72Rl8c5DF9A
key: ghc-typelits-extra-0.3-E6dhYIH37ba72Rl8c5DF9A
license: BSD-2-Clause
copyright: Copyright © 2015-2016, University of Twente,
           2017-2018, QBayLogic B.V.
maintainer: christiaan.baaij@gmail.com
author: Christiaan Baaij
homepage: http://www.clash-lang.org/
synopsis: Additional type-level operations on GHC.TypeLits.Nat
description:
    Additional type-level operations on @GHC.TypeLits.Nat@:
    .
    * @Max@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:max max>
    .
    * @Min@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:min min>
    .
    * @Div@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:div div>
    .
    * @Mod@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:mod mod>
    .
    * @FLog@: type-level equivalent of <https://hackage.haskell.org/package/integer-gmp/docs/GHC-Integer-Logarithms.html#v:integerLogBase-35- integerLogBase#>
    i.e. the exact integer equivalent to @floor (logBase x y)@
    .
    * @CLog@: type-level equivalent of /the ceiling of/ <https://hackage.haskell.org/package/integer-gmp/docs/GHC-Integer-Logarithms.html#v:integerLogBase-35- integerLogBase#>
    i.e. the exact integer equivalent to @ceiling (logBase x y)@
    .
    * @Log@: type-level equivalent of <https://hackage.haskell.org/package/integer-gmp/docs/GHC-Integer-Logarithms.html#v:integerLogBase-35- integerLogBase#>
    where the operation only reduces when @floor (logBase b x) ~ ceiling (logBase b x)@
    .
    * @GCD@: a type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:gcd gcd>
    .
    * @LCM@: a type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:lcm lcm>
    .
    And a custom solver for the above operations defined in
    @GHC.TypeLits.Extra.Solver@ as a GHC type-checker plugin. To use the plugin,
    add the
    .
    @
    OPTIONS_GHC -fplugin GHC.TypeLits.Extra.Solver
    @
    .
    pragma to the header of your file.
category: Type System
abi: 14982345c5c03b9e8674c9bb2d91fffd
exposed: True
exposed-modules:
    GHC.TypeLits.Extra GHC.TypeLits.Extra.Solver
hidden-modules: GHC.TypeLits.Extra.Solver.Unify
                GHC.TypeLits.Extra.Solver.Operations
import-dirs: /usr/lib/ghc-8.6.4/site-local/ghc-typelits-extra-0.3
library-dirs: /usr/lib/ghc-8.6.4/site-local/ghc-typelits-extra-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/ghc-typelits-extra-0.3
hs-libraries: HSghc-typelits-extra-0.3-E6dhYIH37ba72Rl8c5DF9A
depends:
    base-4.12.0.0 ghc-8.6.4 ghc-prim-0.5.3
    ghc-tcplugins-extra-0.3-Ebvoj9UwWkK1Ku3MQihAC5
    ghc-typelits-knownnat-0.6-HbX8DbVdlQT4DUsIn8iTTz
    ghc-typelits-natnormalise-0.6.2-8md7gx558vVJbkEHpPe9rU
    integer-gmp-1.0.2.0 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-ghc-typelits-extra/html/ghc-typelits-extra.haddock
haddock-html: /usr/share/doc/haskell-ghc-typelits-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-typelits-extra-0.3-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ghc-typelits-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ghc-typelits-extra
version: 0.3
id: ghc-typelits-extra-0.3-G8tEZCIGEdbFPIPALuMQ2R
key: ghc-typelits-extra-0.3-G8tEZCIGEdbFPIPALuMQ2R
license: BSD-2-Clause
copyright: Copyright © 2015-2016, University of Twente,
           2017-2018, QBayLogic B.V.
maintainer: christiaan.baaij@gmail.com
author: Christiaan Baaij
homepage: http://www.clash-lang.org/
synopsis: Additional type-level operations on GHC.TypeLits.Nat
description:
    Additional type-level operations on @GHC.TypeLits.Nat@:
    .
    * @Max@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:max max>
    .
    * @Min@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:min min>
    .
    * @Div@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:div div>
    .
    * @Mod@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:mod mod>
    .
    * @FLog@: type-level equivalent of <https://hackage.haskell.org/package/integer-gmp/docs/GHC-Integer-Logarithms.html#v:integerLogBase-35- integerLogBase#>
    i.e. the exact integer equivalent to @floor (logBase x y)@
    .
    * @CLog@: type-level equivalent of /the ceiling of/ <https://hackage.haskell.org/package/integer-gmp/docs/GHC-Integer-Logarithms.html#v:integerLogBase-35- integerLogBase#>
    i.e. the exact integer equivalent to @ceiling (logBase x y)@
    .
    * @Log@: type-level equivalent of <https://hackage.haskell.org/package/integer-gmp/docs/GHC-Integer-Logarithms.html#v:integerLogBase-35- integerLogBase#>
    where the operation only reduces when @floor (logBase b x) ~ ceiling (logBase b x)@
    .
    * @GCD@: a type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:gcd gcd>
    .
    * @LCM@: a type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:lcm lcm>
    .
    And a custom solver for the above operations defined in
    @GHC.TypeLits.Extra.Solver@ as a GHC type-checker plugin. To use the plugin,
    add the
    .
    @
    OPTIONS_GHC -fplugin GHC.TypeLits.Extra.Solver
    @
    .
    pragma to the header of your file.
category: Type System
abi: 96256e7adf73c69ecdea9e356362eeed
exposed: True
exposed-modules:
    GHC.TypeLits.Extra GHC.TypeLits.Extra.Solver
hidden-modules: GHC.TypeLits.Extra.Solver.Unify
                GHC.TypeLits.Extra.Solver.Operations
import-dirs: /usr/lib/ghc-8.6.4/site-local/ghc-typelits-extra-0.3
library-dirs: /usr/lib/ghc-8.6.4/site-local/ghc-typelits-extra-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/ghc-typelits-extra-0.3
hs-libraries: HSghc-typelits-extra-0.3-G8tEZCIGEdbFPIPALuMQ2R
depends:
    base-4.12.0.0 ghc-8.6.4 ghc-prim-0.5.3
    ghc-tcplugins-extra-0.3-Ebvoj9UwWkK1Ku3MQihAC5
    ghc-typelits-knownnat-0.6-D1UkJ6EtvMh8QGK1jtbaO
    ghc-typelits-natnormalise-0.6.2-KR0Q347vLWB1d077vIhGJJ
    integer-gmp-1.0.2.0 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-ghc-typelits-extra/html/ghc-typelits-extra.haddock
haddock-html: /usr/share/doc/haskell-ghc-typelits-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
